EXPORTS
	??0CMsvTestUtils@@IAE@AAVRTest@@@Z @ 1 NONAME ; protected: __thiscall CMsvTestUtils::CMsvTestUtils(class RTest &)
	??0CTestActive@@QAE@XZ @ 2 NONAME ; public: __thiscall CTestActive::CTestActive(void)
	??0CTestTimer@@IAE@XZ @ 3 NONAME ; protected: __thiscall CTestTimer::CTestTimer(void)
	??0CTestUtils@@IAE@AAVRTest@@@Z @ 4 NONAME ; protected: __thiscall CTestUtils::CTestUtils(class RTest &)
	??0TestMsvOperationTimer@@IAE@PAVCConsoleBase@@PAVCMsvOperation@@AAVRTest@@@Z @ 5 NONAME ; protected: __thiscall TestMsvOperationTimer::TestMsvOperationTimer(class CConsoleBase *,class CMsvOperation *,class RTest &)
	??1CMsvTestUtils@@MAE@XZ @ 6 NONAME ; protected: virtual __thiscall CMsvTestUtils::~CMsvTestUtils(void)
	??1CScriptFile@@UAE@XZ @ 7 NONAME ; public: virtual __thiscall CScriptFile::~CScriptFile(void)
	??1CScriptSection@@UAE@XZ @ 8 NONAME ; public: virtual __thiscall CScriptSection::~CScriptSection(void)
	??1CScriptSectionItem@@UAE@XZ @ 9 NONAME ; public: virtual __thiscall CScriptSectionItem::~CScriptSectionItem(void)
	??1CTestActive@@UAE@XZ @ 10 NONAME ; public: virtual __thiscall CTestActive::~CTestActive(void)
	??1CTestUtils@@MAE@XZ @ 11 NONAME ; protected: virtual __thiscall CTestUtils::~CTestUtils(void)
	??1CTestUtilsWatcherStarter@@UAE@XZ @ 12 NONAME ; public: virtual __thiscall CTestUtilsWatcherStarter::~CTestUtilsWatcherStarter(void)
	?AddItemIfNotExistL@CScriptSection@@QAEXABVTDesC16@@0@Z @ 13 NONAME ; public: void __thiscall CScriptSection::AddItemIfNotExistL(class TDesC16 const &,class TDesC16 const &)
	?AddItemL@CScriptSection@@QAEAAVCScriptSectionItem@@ABVTDesC16@@0@Z @ 14 NONAME ; public: class CScriptSectionItem & __thiscall CScriptSection::AddItemL(class TDesC16 const &,class TDesC16 const &)
	?AfterReq@CTestTimer@@QAEXVTTimeIntervalMicroSeconds32@@AAVTRequestStatus@@@Z @ 15 NONAME ; public: void __thiscall CTestTimer::AfterReq(class TTimeIntervalMicroSeconds32,class TRequestStatus &)
	?AppendScheduleTimeL@CMsvTestUtils@@QAEHJAAVTDes16@@@Z @ 16 NONAME ; public: int __thiscall CMsvTestUtils::AppendScheduleTimeL(long,class TDes16 &)
	?AppendText@CTestUtils@@IAEXABVTDesC16@@AAVTDes16@@H@Z @ 17 NONAME ; protected: void __thiscall CTestUtils::AppendText(class TDesC16 const &,class TDes16 &,int)
	?AppendToMenuL@CTestUtils@@QAEXABVTDesC16@@@Z @ 18 NONAME ; public: void __thiscall CTestUtils::AppendToMenuL(class TDesC16 const &)
	?CleanMessageFolderL@CMsvTestUtils@@QAEXXZ @ 19 NONAME ; public: void __thiscall CMsvTestUtils::CleanMessageFolderL(void)
	?ClearLogL@CTestUtils@@QAEXABVCLogFilter@@@Z @ 20 NONAME ; public: void __thiscall CTestUtils::ClearLogL(class CLogFilter const &)
	?ClearScreen@CTestUtils@@QAEXH@Z @ 21 NONAME ; public: void __thiscall CTestUtils::ClearScreen(int)
	?ConstructL@CMsvTestUtils@@MAEXI@Z @ 22 NONAME ; protected: virtual void __thiscall CMsvTestUtils::ConstructL(unsigned int)
	?ConstructL@CTestUtils@@MAEXXZ @ 23 NONAME ; protected: virtual void __thiscall CTestUtils::ConstructL(void)
	?ConstructL@TestMsvOperationTimer@@QAEXXZ @ 24 NONAME ; public: void __thiscall TestMsvOperationTimer::ConstructL(void)
	?CopyLC@CScriptSection@@QAEPAV1@XZ @ 25 NONAME ; public: class CScriptSection * __thiscall CScriptSection::CopyLC(void)
	?CreateAllTestDirectories@CMsvTestUtils@@UAEXXZ @ 26 NONAME ; public: virtual void __thiscall CMsvTestUtils::CreateAllTestDirectories(void)
	?CreateAllTestDirectories@CTestUtils@@UAEXXZ @ 27 NONAME ; public: virtual void __thiscall CTestUtils::CreateAllTestDirectories(void)
	?CreateContactL@CTestUtils@@QAEJABVTDesC16@@000H@Z @ 28 NONAME ; public: long __thiscall CTestUtils::CreateContactL(class TDesC16 const &,class TDesC16 const &,class TDesC16 const &,class TDesC16 const &,int)
	?CreateRegistryObjectAndControlL@CMsvTestUtils@@QAEXXZ @ 29 NONAME ; public: void __thiscall CMsvTestUtils::CreateRegistryObjectAndControlL(void)
	?CreateServerMtmRegL@CMsvTestUtils@@IAEXVTUid@@ABVTDesC16@@ABVTMsvTestDllInfo@@22201@Z @ 30 NONAME ; protected: void __thiscall CMsvTestUtils::CreateServerMtmRegL(class TUid,class TDesC16 const &,class TMsvTestDllInfo const &,class TMsvTestDllInfo const &,class TMsvTestDllInfo const &,class TMsvTestDllInfo const &,class TUid,class TDesC16 const &)
	?CreateServiceL@CMsvTestUtils@@IAEJVTUid@@HH@Z @ 31 NONAME ; protected: long __thiscall CMsvTestUtils::CreateServiceL(class TUid,int,int)
	?DeleteContactsFileL@CTestUtils@@QAEXXZ @ 32 NONAME ; public: void __thiscall CTestUtils::DeleteContactsFileL(void)
	?DeleteItemsL@CScriptSection@@QAEXABVTDesC16@@@Z @ 33 NONAME ; public: void __thiscall CScriptSection::DeleteItemsL(class TDesC16 const &)
	?DeleteServiceL@CMsvTestUtils@@IAEXVTUid@@@Z @ 34 NONAME ; protected: void __thiscall CMsvTestUtils::DeleteServiceL(class TUid)
	?DisplayChildL@CMsvTestUtils@@IAEXABVTMsvEntry@@@Z @ 35 NONAME ; protected: void __thiscall CMsvTestUtils::DisplayChildL(class TMsvEntry const &)
	?DisplayFile@CTestUtils@@QAEHABVTDesC16@@@Z @ 36 NONAME ; public: int __thiscall CTestUtils::DisplayFile(class TDesC16 const &)
	?DisplayLogL@CTestUtils@@QAEXABVCLogFilter@@H@Z @ 37 NONAME ; public: void __thiscall CTestUtils::DisplayLogL(class CLogFilter const &,int)
	?DisplayMenu@CTestUtils@@QAEHABVTDesC16@@HHHH@Z @ 38 NONAME ; public: int __thiscall CTestUtils::DisplayMenu(class TDesC16 const &,int,int,int,int)
	?DoBuf@CTestUtils@@IAEXAAVTDes8@@ABVTDesC16@@1@Z @ 39 NONAME ; protected: void __thiscall CTestUtils::DoBuf(class TDes8 &,class TDesC16 const &,class TDesC16 const &)
	?DoBuf@CTestUtils@@IAEXAAVTDes8@@ABVTDesC16@@ABVTDesC8@@@Z @ 40 NONAME ; protected: void __thiscall CTestUtils::DoBuf(class TDes8 &,class TDesC16 const &,class TDesC8 const &)
	?DoCancel@CTestActive@@MAEXXZ @ 41 NONAME ; protected: virtual void __thiscall CTestActive::DoCancel(void)
	?DoCancel@TestMsvOperationTimer@@UAEXXZ @ 42 NONAME ; public: virtual void __thiscall TestMsvOperationTimer::DoCancel(void)
	?Find@CMsvConfigEntrySelection@@QBEPBVTMsvConfigEntry@@ABVTDesC16@@@Z @ 43 NONAME ; public: class TMsvConfigEntry const * __thiscall CMsvConfigEntrySelection::Find(class TDesC16 const &)const 
	?FindChildrenL@CMsvTestUtils@@QAEXJABV?$TBuf@$0BAA@@@HH@Z @ 44 NONAME ; public: void __thiscall CMsvTestUtils::FindChildrenL(long,class TBuf<256> const &,int,int)
	?FindChildrenL@CMsvTestUtils@@QAEXJHH@Z @ 45 NONAME ; public: void __thiscall CMsvTestUtils::FindChildrenL(long,int,int)
	?FindPos@CMsvConfigEntrySelection@@QBEHABVTDesC16@@@Z @ 46 NONAME ; public: int __thiscall CMsvConfigEntrySelection::FindPos(class TDesC16 const &)const 
	?GetNextWord@CScriptFile@@SAHAAVTLex16@@VTChar@@AAH@Z @ 47 NONAME ; public: static int __cdecl CScriptFile::GetNextWord(class TLex16 &,class TChar,int &)
	?GetNextWord@CScriptFile@@SAHAAVTLex16@@VTChar@@AAVTPtrC16@@@Z @ 48 NONAME ; public: static int __cdecl CScriptFile::GetNextWord(class TLex16 &,class TChar,class TPtrC16 &)
	?GoClientSideL@CMsvTestUtils@@QAEXXZ @ 49 NONAME ; public: void __thiscall CMsvTestUtils::GoClientSideL(void)
	?GoServerSideL@CMsvTestUtils@@QAEXXZ @ 50 NONAME ; public: void __thiscall CMsvTestUtils::GoServerSideL(void)
	?InstallMtmGroupL@CMsvTestUtils@@IAEXABVTDesC16@@@Z @ 51 NONAME ; protected: void __thiscall CMsvTestUtils::InstallMtmGroupL(class TDesC16 const &)
	?InstantiateClientMtmL@CMsvTestUtils@@IAEPAVCBaseMtm@@VTUid@@J@Z @ 52 NONAME ; protected: class CBaseMtm * __thiscall CMsvTestUtils::InstantiateClientMtmL(class TUid,long)
	?InstantiateServerMtmL@CMsvTestUtils@@IAEPAVCBaseServerMtm@@VTUid@@J@Z @ 53 NONAME ; protected: class CBaseServerMtm * __thiscall CMsvTestUtils::InstantiateServerMtmL(class TUid,long)
	?Int@TMsvConfigEntry@@QBEHXZ @ 54 NONAME ; public: int __thiscall TMsvConfigEntry::Int(void)const 
	?IssueRequest@TestMsvOperationTimer@@QAEXXZ @ 55 NONAME ; public: void __thiscall TestMsvOperationTimer::IssueRequest(void)
	?Item@CScriptSection@@QAEPAVCScriptSectionItem@@ABVTDesC16@@@Z @ 56 NONAME ; public: class CScriptSectionItem * __thiscall CScriptSection::Item(class TDesC16 const &)
	?ItemValue@CScriptFile@@QAEABVTDesC16@@ABV2@00@Z @ 57 NONAME ; public: class TDesC16 const & __thiscall CScriptFile::ItemValue(class TDesC16 const &,class TDesC16 const &,class TDesC16 const &)
	?ItemValue@CScriptFile@@QAEHABVTDesC16@@0H@Z @ 58 NONAME ; public: int __thiscall CScriptFile::ItemValue(class TDesC16 const &,class TDesC16 const &,int)
	?ItemValue@CScriptSection@@QAEABVTDesC16@@ABV2@0@Z @ 59 NONAME ; public: class TDesC16 const & __thiscall CScriptSection::ItemValue(class TDesC16 const &,class TDesC16 const &)
	?ItemValue@CScriptSection@@QAEHABVTDesC16@@H@Z @ 60 NONAME ; public: int __thiscall CScriptSection::ItemValue(class TDesC16 const &,int)
	?ItemValueL@CScriptFile@@SAHAAVCTestUtils@@ABVTDesC16@@111H@Z @ 61 NONAME ; public: static int __cdecl CScriptFile::ItemValueL(class CTestUtils &,class TDesC16 const &,class TDesC16 const &,class TDesC16 const &,class TDesC16 const &,int)
	?ItemValueLC@CScriptFile@@SAPAVHBufC16@@AAVCTestUtils@@ABVTDesC16@@1111@Z @ 62 NONAME ; public: static class HBufC16 * __cdecl CScriptFile::ItemValueLC(class CTestUtils &,class TDesC16 const &,class TDesC16 const &,class TDesC16 const &,class TDesC16 const &,class TDesC16 const &)
	?ListChildrenL@CMsvTestUtils@@MAEXAAVRFile@@AAVCDir@@AAH2HH@Z @ 63 NONAME ; protected: virtual void __thiscall CMsvTestUtils::ListChildrenL(class RFile &,class CDir &,int &,int &,int,int)
	?MenuCount@CTestUtils@@QBEHXZ @ 64 NONAME ; public: int __thiscall CTestUtils::MenuCount(void)const 
	?NavigateMessageStoreL@CMsvTestUtils@@QAEXJ@Z @ 65 NONAME ; public: void __thiscall CMsvTestUtils::NavigateMessageStoreL(long)
	?NewL@CMsvConfigEntrySelection@@SAPAV1@AAVRFs@@ABVTDesC16@@@Z @ 66 NONAME ; public: static class CMsvConfigEntrySelection * __cdecl CMsvConfigEntrySelection::NewL(class RFs &,class TDesC16 const &)
	?NewL@CTestTimer@@SAPAV1@XZ @ 67 NONAME ; public: static class CTestTimer * __cdecl CTestTimer::NewL(void)
	?NewL@CTestUtilsWatcherStarter@@SAPAV1@AAVTRequestStatus@@VTTimeIntervalMicroSeconds32@@H@Z @ 68 NONAME ; public: static class CTestUtilsWatcherStarter * __cdecl CTestUtilsWatcherStarter::NewL(class TRequestStatus &,class TTimeIntervalMicroSeconds32,int)
	?NewL@CTestUtilsWatcherStarter@@SAPAV1@H@Z @ 69 NONAME ; public: static class CTestUtilsWatcherStarter * __cdecl CTestUtilsWatcherStarter::NewL(int)
	?NewLC@CScriptFile@@SAPAV1@AAVCTestUtils@@ABVTDesC16@@1@Z @ 70 NONAME ; public: static class CScriptFile * __cdecl CScriptFile::NewLC(class CTestUtils &,class TDesC16 const &,class TDesC16 const &)
	?NewLC@CScriptFile@@SAPAV1@AAVCTestUtils@@ABVTDesC16@@@Z @ 71 NONAME ; public: static class CScriptFile * __cdecl CScriptFile::NewLC(class CTestUtils &,class TDesC16 const &)
	?NewLC@CScriptSection@@SAPAV1@ABVTDesC16@@@Z @ 72 NONAME ; public: static class CScriptSection * __cdecl CScriptSection::NewLC(class TDesC16 const &)
	?NewLC@CScriptSection@@SAPAV1@ABVTDesC16@@AAV1@@Z @ 73 NONAME ; public: static class CScriptSection * __cdecl CScriptSection::NewLC(class TDesC16 const &,class CScriptSection &)
	?NewLC@CScriptSectionItem@@SAPAV1@AAVCScriptSection@@ABVTDesC16@@1@Z @ 74 NONAME ; public: static class CScriptSectionItem * __cdecl CScriptSectionItem::NewLC(class CScriptSection &,class TDesC16 const &,class TDesC16 const &)
	?NewLC@TestMsvOperationTimer@@SAPAV1@PAVCConsoleBase@@PAVCMsvOperation@@AAVRTest@@@Z @ 75 NONAME ; public: static class TestMsvOperationTimer * __cdecl TestMsvOperationTimer::NewLC(class CConsoleBase *,class CMsvOperation *,class RTest &)
	?PrintHex@CTestUtils@@QAEXABVTDesC16@@@Z @ 76 NONAME ; public: void __thiscall CTestUtils::PrintHex(class TDesC16 const &)
	?PrintHex@CTestUtils@@QAEXABVTDesC8@@@Z @ 77 NONAME ; public: void __thiscall CTestUtils::PrintHex(class TDesC8 const &)
	?Printf@CTestUtils@@QAAXV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 78 NONAME ; public: void __cdecl CTestUtils::Printf(class TRefByValue<class TDesC16 const >,...)
	?ReadFileLC@CTestUtils@@QAEPAVHBufC8@@ABVTDesC16@@@Z @ 79 NONAME ; public: class HBufC8 * __thiscall CTestUtils::ReadFileLC(class TDesC16 const &)
	?ReadScriptL@CScriptFile@@QAEXABVTDesC16@@@Z @ 80 NONAME ; public: void __thiscall CScriptFile::ReadScriptL(class TDesC16 const &)
	?RemoveRichtextFormating@CTestUtils@@IAEXAAVTDes16@@@Z @ 81 NONAME ; protected: void __thiscall CTestUtils::RemoveRichtextFormating(class TDes16 &)
	?ReplaceItemL@CScriptSection@@QAEAAVCScriptSectionItem@@ABVTDesC16@@0@Z @ 82 NONAME ; public: class CScriptSectionItem & __thiscall CScriptSection::ReplaceItemL(class TDesC16 const &,class TDesC16 const &)
	?ReplaceL@CScriptFile@@SAXABVTDesC16@@0AAPAVHBufC16@@@Z @ 83 NONAME ; public: static void __cdecl CScriptFile::ReplaceL(class TDesC16 const &,class TDesC16 const &,class HBufC16 * &)
	?ReplaceLC@CScriptFile@@SAPAVHBufC16@@ABVTDesC16@@00@Z @ 84 NONAME ; public: static class HBufC16 * __cdecl CScriptFile::ReplaceLC(class TDesC16 const &,class TDesC16 const &,class TDesC16 const &)
	?Reset@CMsvTestUtils@@UAEXXZ @ 85 NONAME ; public: virtual void __thiscall CMsvTestUtils::Reset(void)
	?ResetMenu@CTestUtils@@QAEXXZ @ 86 NONAME ; public: void __thiscall CTestUtils::ResetMenu(void)
	?ResolveFile@CTestUtils@@QAEHABVTDesC16@@0AAVTParse@@@Z @ 87 NONAME ; public: int __thiscall CTestUtils::ResolveFile(class TDesC16 const &,class TDesC16 const &,class TParse &)
	?ResolveLogFile@CTestUtils@@QAEHABVTDesC16@@AAVTParse@@@Z @ 88 NONAME ; public: int __thiscall CTestUtils::ResolveLogFile(class TDesC16 const &,class TParse &)
	?RunAuto@CTestUtils@@QBEHXZ @ 89 NONAME ; public: int __thiscall CTestUtils::RunAuto(void)const 
	?RunL@CTestActive@@MAEXXZ @ 90 NONAME ; protected: virtual void __thiscall CTestActive::RunL(void)
	?RunL@CTestTimer@@MAEXXZ @ 91 NONAME ; protected: virtual void __thiscall CTestTimer::RunL(void)
	?RunL@TestMsvOperationTimer@@UAEXXZ @ 92 NONAME ; public: virtual void __thiscall TestMsvOperationTimer::RunL(void)
	?ScheduleTime@CMsvTestUtils@@QAEHJAAVTTime@@0AAVTTaskInfo@@@Z @ 93 NONAME ; public: int __thiscall CMsvTestUtils::ScheduleTime(long,class TTime &,class TTime &,class TTaskInfo &)
	?Section@CScriptFile@@QAEPAVCScriptSection@@ABVTDesC16@@@Z @ 94 NONAME ; public: class CScriptSection * __thiscall CScriptFile::Section(class TDesC16 const &)
	?ServiceIdL@CMsvTestUtils@@IAEXVTUid@@AAJPAVCMsvEntrySelection@@@Z @ 95 NONAME ; protected: void __thiscall CMsvTestUtils::ServiceIdL(class TUid,long &,class CMsvEntrySelection *)
	?Set@TMsvConfigEntry@@QAEHABVTDesC16@@@Z @ 96 NONAME ; public: int __thiscall TMsvConfigEntry::Set(class TDesC16 const &)
	?SetFolderType@CMsvTestUtils@@MAEXAAVTMsvEntry@@AAVTPtrC16@@@Z @ 97 NONAME ; protected: virtual void __thiscall CMsvTestUtils::SetFolderType(class TMsvEntry &,class TPtrC16 &)
	?SetLogToConsole@CTestUtils@@QAEHH@Z @ 98 NONAME ; public: int __thiscall CTestUtils::SetLogToConsole(int)
	?SetLogToFile@CTestUtils@@QAEHH@Z @ 99 NONAME ; public: int __thiscall CTestUtils::SetLogToFile(int)
	?SetNameL@CTestUtils@@QAEXAAVCContactItem@@VTUid@@ABVTDesC16@@H@Z @ 100 NONAME ; public: void __thiscall CTestUtils::SetNameL(class CContactItem &,class TUid,class TDesC16 const &,int)
	?SetRunAuto@CTestUtils@@QAEXH@Z @ 101 NONAME ; public: void __thiscall CTestUtils::SetRunAuto(int)
	?SpecifyLogsDir@CMsvTestUtils@@IAEXABV?$TBuf@$0BAA@@@@Z @ 102 NONAME ; protected: void __thiscall CMsvTestUtils::SpecifyLogsDir(class TBuf<256> const &)
	?SpecifyRfc822Dir@CMsvTestUtils@@QAEXABV?$TBuf@$0BAA@@@@Z @ 103 NONAME ; public: void __thiscall CMsvTestUtils::SpecifyRfc822Dir(class TBuf<256> const &)
	?StartL@CTestActive@@QAEXXZ @ 104 NONAME ; public: void __thiscall CTestActive::StartL(void)
	?TestFinish@CTestUtils@@QAEXHH@Z @ 105 NONAME ; public: void __thiscall CTestUtils::TestFinish(int,int)
	?TestHarnessCompleted@CTestUtils@@QAEXXZ @ 106 NONAME ; public: void __thiscall CTestUtils::TestHarnessCompleted(void)
	?TestHarnessFailed@CTestUtils@@QAEXH@Z @ 107 NONAME ; public: void __thiscall CTestUtils::TestHarnessFailed(int)
	?TestStart@CTestUtils@@QAEXH@Z @ 108 NONAME ; public: void __thiscall CTestUtils::TestStart(int)
	?TestStart@CTestUtils@@QAEXHABVTDesC16@@@Z @ 109 NONAME ; public: void __thiscall CTestUtils::TestStart(int,class TDesC16 const &)
	?Version@TMsvConfigEntry@@QBE?AVTVersion@@XZ @ 110 NONAME ; public: class TVersion  __thiscall TMsvConfigEntry::Version(void)const 
	?WriteBodyDataL@CMsvTestUtils@@IAEXJABV?$TBuf@$0BAA@@@AAVCMsvStore@@H@Z @ 111 NONAME ; protected: void __thiscall CMsvTestUtils::WriteBodyDataL(long,class TBuf<256> const &,class CMsvStore &,int)
	?WriteComment@CTestUtils@@QAEXABVTDesC16@@@Z @ 112 NONAME ; public: void __thiscall CTestUtils::WriteComment(class TDesC16 const &)
	?WriteFileDataL@CMsvTestUtils@@IAEXJABV?$TBuf@$0BAA@@@0H@Z @ 113 NONAME ; protected: void __thiscall CMsvTestUtils::WriteFileDataL(long,class TBuf<256> const &,class TBuf<256> const &,int)
	?WriteToFileL@CTestUtils@@IAEXAAVRFile@@AAVTDesC8@@@Z @ 114 NONAME ; protected: void __thiscall CTestUtils::WriteToFileL(class RFile &,class TDesC8 &)
	?WriteToFileL@CTestUtils@@IAEXAAVRFile@@ABVTDesC16@@@Z @ 115 NONAME ; protected: void __thiscall CTestUtils::WriteToFileL(class RFile &,class TDesC16 const &)
	?OpenResourceFileL@CTestUtils@@QAEXABVTDesC16@@AAVRResourceFile@@@Z @ 116 NONAME ; public: void __thiscall CTestUtils::OpenResourceFileL(class TDesC16 const &,class RResourceFile &)
	?ReadResourceStringL@CTestUtils@@QAEXAAVRResourceFile@@HAAVTDes16@@@Z @ 117 NONAME ; public: void __thiscall CTestUtils::ReadResourceStringL(class RResourceFile &,int,class TDes16 &)
	?ReadResourceStringL@CTestUtils@@QAEXABVTDesC16@@HAAVTDes16@@@Z @ 118 NONAME ; public: void __thiscall CTestUtils::ReadResourceStringL(class TDesC16 const &,int,class TDes16 &)
	?CopyToSimTsyConfigFileL@CTestUtils@@SAXAAVRFs@@ABVTDesC16@@@Z @ 119 NONAME ; public: static void __cdecl CTestUtils::CopyToSimTsyConfigFileL(class RFs &,class TDesC16 const &)
	?SetSimTsyTestNumberL@CTestUtils@@SAXH@Z @ 120 NONAME ; public: static void __cdecl CTestUtils::SetSimTsyTestNumberL(int)
	?SeekLogFile@CTestUtils@@QAEHW4TSeek@@AAH@Z @ 121 NONAME ; public: int __thiscall CTestUtils::SeekLogFile(enum TSeek,int &)

